@@ -56,8 +56,6 @@ int main(int argc, char **argv)
     QCommandLineParser parser;
     KAboutData::setApplicationData(about);
     KCrash::initialize();
-    parser.addVersionOption();
-    parser.addHelpOption();
     about.setupCommandLine(&parser);
     parser.process(app);
     about.processCommandLine(&parser);
@@ -65,7 +63,7 @@ int main(int argc, char **argv)
     app.setWindowIcon(QIcon::fromTheme(QStringLiteral("kdiamond")));
 
     //resource directory for KNewStuff2 (this call causes the directory to be created; its existence is necessary for the downloader)
-    QStandardPaths::writableLocation(QStandardPaths::DataLocation) + QLatin1String("/themes/");
+    QStandardPaths::writableLocation(QStandardPaths::AppDataLocation) + QLatin1String("/themes/");
 
     Kg::difficulty()->addStandardLevelRange(
         KgDifficultyLevel::VeryEasy,
